{% extends ac_app_name|add:'/auth/base.html' %}
{% block content %}
<div class="d-flex align-items-center pt-xl-5 px-5 ms-xl-4 pt-5 pt-xl-0 mt-xl-5">
    <div style="width: 100%;">
        <div class="alert alert-info" role="alert">
            {{_('reset_password_complete_message')}}
            <!--                            Your password has been set.  You may go ahead and log in now.-->
        </div>
        <p class="mx-0 mb-0">{{_('already_have_an_account')}}&nbsp;<a href="{% url 'login' %}"
                                                                      class="link-info">{{_('login')}}</a>
        </p>
        <p class="mx-0 mt-0">{{_('dont_have_an_account')}}&nbsp;<a href="{% url '__account_register' %}"
                                                                   class="link-info">{{_('register')}}</a>
        </p>
    </div>
</div>
{% endblock %}